/*	
	Proyecto TFG:
		AMH VIDA
	Ao:
		2011-2012.
	Version:
		1.0
	Fecha de ultima modificacion:
		18-Jul-2012.
	Fuente original:
		http://www.qtcentre.org/threads/11655-OpenCV-integration
	Modificacin:
		Jose Luis Martinez Jimenez.
	Tutores:
		Francisco Javier Finat Codes.
		Valentn Cardeoso Payo
	Descripcion:
		Trackcontroller es el que coordina todo el proco, creando
		el buffer de frames. ste crea dos hilos, Capturethread y
		Processingthread, adems de establecer un filter, que es 
		el encargado de presentar la imagen.
*/
#include "trackcontroller.h"
#include "processingthread.h"
#include "imagebuffer.h"

#include <QDebug>

TrackController::TrackController() : frameRate(15), frameSize(CaptureThread::Size320) {
	
	imageBuffer = new ImageBuffer(20);
	captureThread = new CaptureThread(imageBuffer);
	processingThread = new ProcessingThread(imageBuffer);
	//processingThread->start();
	connect(captureThread, SIGNAL(videoEnds()), this, SLOT(videoEndsEvent()));
}

void TrackController::openFile(std::string dir){
	captureThread->setFilename(dir);
}

void TrackController::toggleImage(){
	processingThread->toggleImage();
}

void TrackController::startTracking() {
	captureThread->startCapture(frameRate, frameSize);
	qDebug() << "About to start the capture thread";
	captureThread->start(QThread::IdlePriority);
	qDebug() << "Started the capture thread";
	processingThread->start();
	processingThread->playProcessing();
	
}

bool TrackController::isTracking() {
	return captureThread->isCapturing();
}

void TrackController::stopTracking() {
	captureThread->stopCapture();;
	processingThread->stop();
}

void TrackController::videoEndsEvent(){
	Ret *r=Ret::getRet();
	r->setEndFile(true);
	captureThread->stopCapture();
	processingThread->stopProcessing();
}

void TrackController::pauseTracking() {
	captureThread->pauseCapture();
	processingThread->pauseProcessing();
}

void TrackController::setRootFilter(Filter* filter) {
	processingThread->setRootFilter(filter);
}

double TrackController::getFPS() {
	return captureThread->getFPS();
}

void TrackController::setPrevView(bool selected){
	processingThread->setPrevView(selected);
}